"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _draftJs = require("draft-js");

var _Code = _interopRequireDefault(require("./components/Code"));

var _constants = require("./constants");

var _image = _interopRequireDefault(require("./decorators/image"));

var _link = _interopRequireDefault(require("./decorators/link"));

var _changeCurrentBlockType = _interopRequireDefault(require("./modifiers/changeCurrentBlockType"));

var _handleBlockType = _interopRequireDefault(require("./modifiers/handleBlockType"));

var _handleImage = _interopRequireDefault(require("./modifiers/handleImage"));

var _handleInlineStyle = _interopRequireDefault(require("./modifiers/handleInlineStyle"));

var _handleLink = _interopRequireDefault(require("./modifiers/handleLink"));

var _handleNewCodeBlock = _interopRequireDefault(require("./modifiers/handleNewCodeBlock"));

var _insertEmptyBlock = _interopRequireDefault(require("./modifiers/insertEmptyBlock"));

var _insertText = _interopRequireDefault(require("./modifiers/insertText"));

var _leaveList = _interopRequireDefault(require("./modifiers/leaveList"));

var _resetInlineStyle = _interopRequireDefault(require("./modifiers/resetInlineStyle"));

var _splitBlockAndChange = _interopRequireDefault(require("./modifiers/splitBlockAndChange"));

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const defaultLanguages = {
  bash: "Bash",
  c: "C",
  cpp: "C++",
  css: "CSS",
  go: "Go",
  html: "HTML",
  java: "Java",
  js: "JavaScript",
  kotlin: "Kotlin",
  mathml: "MathML",
  perl: "Perl",
  ruby: "Ruby",
  scala: "Scala",
  sql: "SQL",
  svg: "SVG",
  swift: "Swift"
};

function inLink(editorState) {
  const selection = editorState.getSelection();
  const contentState = editorState.getCurrentContent();
  const block = contentState.getBlockForKey(selection.getAnchorKey());
  const entityKey = block.getEntityAt(selection.getFocusOffset());
  return entityKey != null && contentState.getEntity(entityKey).getType() === "LINK";
}

function inCodeBlock(editorState) {
  const startKey = editorState.getSelection().getStartKey();

  if (startKey) {
    const currentBlockType = editorState.getCurrentContent().getBlockForKey(startKey).getType();
    if (currentBlockType === "code-block") return true;
  }

  return false;
}

function checkCharacterForState(config, editorState, character) {
  let newEditorState = (0, _handleBlockType.default)(config.features.block, editorState, character);

  if (editorState === newEditorState && config.features.inline.includes("IMAGE")) {
    newEditorState = (0, _handleImage.default)(editorState, character, config.entityType.IMAGE);
  }

  if (editorState === newEditorState && config.features.inline.includes("LINK")) {
    newEditorState = (0, _handleLink.default)(editorState, character, config.entityType.LINK);
  }

  if (newEditorState === editorState && config.features.block.includes("CODE")) {
    const contentState = editorState.getCurrentContent();
    const selection = editorState.getSelection();
    const key = selection.getStartKey();
    const currentBlock = contentState.getBlockForKey(key);
    const text = currentBlock.getText();
    const type = currentBlock.getType();
    if (type !== "code-block" && _constants.CODE_BLOCK_REGEX.test(text)) newEditorState = (0, _handleNewCodeBlock.default)(editorState);
  }

  if (editorState === newEditorState) {
    newEditorState = (0, _handleInlineStyle.default)(config.features.inline, editorState, character);
  }

  return newEditorState;
}

function checkReturnForState(config, editorState, ev) {
  let newEditorState = editorState;
  const contentState = editorState.getCurrentContent();
  const selection = editorState.getSelection();
  const isCollapsed = selection.isCollapsed();
  const key = selection.getStartKey();
  const endOffset = selection.getEndOffset();
  const currentBlock = contentState.getBlockForKey(key);
  const blockLength = currentBlock.getLength();
  const type = currentBlock.getType();
  const text = currentBlock.getText();

  if (/-list-item$/.test(type) && text === "") {
    newEditorState = (0, _leaveList.default)(editorState);
  }

  const isHeader = /^header-/.test(type);
  const isBlockQuote = type === "blockquote";
  const isAtEndOfLine = endOffset === blockLength;
  const atEndOfHeader = isHeader && isAtEndOfLine;
  const atEndOfBlockQuote = isBlockQuote && isAtEndOfLine;

  if (newEditorState === editorState && isCollapsed && (atEndOfHeader || atEndOfBlockQuote)) {
    // transform markdown (if we aren't in a codeblock that is)
    if (!inCodeBlock(editorState)) {
      newEditorState = checkCharacterForState(config, newEditorState, "\n");
    }

    if (newEditorState === editorState) {
      newEditorState = (0, _insertEmptyBlock.default)(newEditorState);
    } else {
      newEditorState = _draftJs.RichUtils.toggleBlockType(newEditorState, type);
    }
  } else if (isCollapsed && (isHeader || isBlockQuote) && !isAtEndOfLine) {
    newEditorState = (0, _splitBlockAndChange.default)(newEditorState);
  }

  if (newEditorState === editorState && type !== "code-block" && config.features.block.includes("CODE") && _constants.CODE_BLOCK_REGEX.test(text)) {
    newEditorState = (0, _handleNewCodeBlock.default)(editorState);
  }

  if (newEditorState === editorState && type === "code-block") {
    if (/```\s*$/.test(text)) {
      newEditorState = (0, _changeCurrentBlockType.default)(newEditorState, type, text.replace(/```\s*$/, ""));
      newEditorState = (0, _insertEmptyBlock.default)(newEditorState);
    } else if (ev.shiftKey) {
      newEditorState = (0, _insertEmptyBlock.default)(newEditorState);
    } else {
      newEditorState = (0, _insertText.default)(editorState, "\n");
    }
  }

  return newEditorState;
}

const unstickyInlineStyles = (character, editorState) => {
  const selection = editorState.getSelection();
  if (!selection.isCollapsed()) return editorState;

  if (editorState.getLastChangeType() !== "md-to-inline-style") {
    return editorState;
  }

  const startOffset = selection.getStartOffset();
  const content = editorState.getCurrentContent();
  const block = content.getBlockForKey(selection.getStartKey());
  const previousBlock = content.getBlockBefore(block.getKey());
  const entity = block.getEntityAt(startOffset - 1);
  if (entity !== null) return editorState; // If we're currently in a style, but the next character doesn't have a style (or doesn't exist)
  // we insert the characters manually without the inline style to "unsticky" them

  if (!startOffset && previousBlock) {
    // If we're in the beginning of the line we have to check styles of the previous block
    const previousBlockStyle = previousBlock.getInlineStyleAt(previousBlock.getText().length - 1);
    if (previousBlockStyle.size === 0) return editorState;
  } else {
    const style = block.getInlineStyleAt(startOffset - 1);
    if (style.size === 0) return editorState;
  }

  const nextStyle = block.getInlineStyleAt(startOffset);
  if (nextStyle.size !== 0) return editorState;

  const newContent = _draftJs.Modifier.insertText(content, selection, character);

  return _draftJs.EditorState.push(editorState, newContent, "insert-characters");
};

const defaultConfig = {
  renderLanguageSelect: _utils.defaultRenderSelect,
  languages: defaultLanguages,
  features: {
    inline: _constants.defaultInlineWhitelist,
    block: _constants.defaultBlockWhitelist
  },
  entityType: _constants.ENTITY_TYPE
};

const createMarkdownPlugin = function createMarkdownPlugin() {
  let _config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  const store = {};

  const config = _objectSpread({}, defaultConfig, {}, _config, {
    features: _objectSpread({}, defaultConfig.features, {}, _config.features),
    entityType: _objectSpread({}, defaultConfig.entityType, {}, _config.entityType)
  });

  return {
    store,
    decorators: [(0, _link.default)({
      entityType: config.entityType.LINK
    }), (0, _image.default)({
      entityType: config.entityType.IMAGE
    })],

    initialize(_ref) {
      let {
        setEditorState,
        getEditorState
      } = _ref;
      store.setEditorState = setEditorState;
      store.getEditorState = getEditorState;
    },

    blockStyleFn(block) {
      switch (block.getType()) {
        default:
          break;
      }

      return null;
    },

    blockRendererFn(block, _ref2) {
      let {
        setReadOnly,
        getReadOnly,
        setEditorState,
        getEditorState,
        getEditorRef
      } = _ref2;

      switch (block.getType()) {
        case _constants.CODE_BLOCK_TYPE:
          {
            return {
              component: _Code.default,
              props: {
                setEditorState,
                renderLanguageSelect: config.renderLanguageSelect,
                languages: config.languages,
                getReadOnly,
                setReadOnly,
                language: block.getData().get("language"),
                getEditorState
              }
            };
          }

        default:
          return null;
      }
    },

    handleReturn(ev, editorState, _ref3) {
      let {
        setEditorState
      } = _ref3;
      if (inLink(editorState)) return "not-handled";
      let newEditorState = checkReturnForState(config, editorState, ev);
      const selection = newEditorState.getSelection(); // exit code blocks

      if (inCodeBlock(editorState) && !Object.is(editorState.getImmutable(), newEditorState.getImmutable())) {
        setEditorState(newEditorState);
        return "handled";
      }

      newEditorState = checkCharacterForState(config, newEditorState, "\n");
      let content = newEditorState.getCurrentContent(); // if there are actually no changes but the editorState has a
      // current inline style we want to split the block

      if (Object.is(editorState.getImmutable(), newEditorState.getImmutable()) && editorState.getCurrentInlineStyle().size > 0) {
        content = _draftJs.Modifier.splitBlock(content, selection);
      }

      newEditorState = (0, _resetInlineStyle.default)(newEditorState);

      if (editorState !== newEditorState) {
        setEditorState(_draftJs.EditorState.push(newEditorState, content, "split-block"));
        return "handled";
      }

      return "not-handled";
    },

    handleBeforeInput(character, editorState, eventTimeStamp, _ref4) {
      let {
        setEditorState
      } = _ref4;
      // If we're in a code block - don't transform markdown
      if (inCodeBlock(editorState)) return "not-handled"; // If we're in a link - don't transform markdown

      if (inLink(editorState)) return "not-handled";
      const unsticky = unstickyInlineStyles(character, editorState);

      if (editorState !== unsticky) {
        setEditorState(unsticky);
        return "handled";
      }

      const newEditorState = checkCharacterForState(config, editorState, character);

      if (editorState !== newEditorState) {
        setEditorState(newEditorState);
        return "handled";
      }

      return "not-handled";
    },

    handlePastedText(text, html, editorState, _ref5) {
      let {
        setEditorState
      } = _ref5;

      if (inCodeBlock(editorState)) {
        setEditorState((0, _insertText.default)(editorState, text));
        return "handled";
      }

      return "not-handled";
    },

    handleKeyCommand(command, editorState, _ref6) {
      let {
        setEditorState
      } = _ref6;

      switch (command) {
        case "backspace":
          {
            // When a styled block is the first thing in the editor,
            // you cannot delete it. Typing backspace only deletes the content
            // but never deletes the block styling.
            // This piece of code fixes the issue by changing the block type
            // to 'unstyled' if we're on the first block of the editor and it's empty
            const selection = editorState.getSelection();
            const currentBlockKey = selection.getStartKey();
            if (!currentBlockKey) return "not-handled";
            const content = editorState.getCurrentContent();
            const currentBlock = content.getBlockForKey(currentBlockKey);
            const firstBlock = content.getFirstBlock();
            if (firstBlock !== currentBlock) return "not-handled";
            const currentBlockType = currentBlock.getType();
            const isEmpty = currentBlock.getLength() === 0;
            if (!isEmpty || currentBlockType === "unstyled") return "not-handled";
            setEditorState((0, _changeCurrentBlockType.default)(editorState, "unstyled", ""));
            return "handled";
          }

        default:
          {
            return "not-handled";
          }
      }
    }

  };
};

var _default = createMarkdownPlugin;
exports.default = _default;