"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _immutable = require("immutable");

var _draftJs = require("draft-js");

var _removeInlineStyles = _interopRequireDefault(require("./removeInlineStyles"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const changeCurrentInlineStyle = (editorState, matchArr, style) => {
  const currentContent = editorState.getCurrentContent();
  const selection = editorState.getSelection();
  const key = selection.getStartKey();
  const {
    index
  } = matchArr;
  const blockMap = currentContent.getBlockMap();
  const block = blockMap.get(key);
  const currentInlineStyle = block.getInlineStyleAt(index); // do not modify the text if it is inside code style

  const hasCodeStyle = currentInlineStyle.find(style => style === "CODE");

  if (hasCodeStyle) {
    return editorState;
  }

  const focusOffset = index + matchArr[0].length;

  const wordSelection = _draftJs.SelectionState.createEmpty(key).merge({
    anchorOffset: index,
    focusOffset
  });

  let newEditorState = editorState; // remove all styles if applying code style

  if (style === "CODE") {
    newEditorState = (0, _removeInlineStyles.default)(newEditorState, wordSelection);
  }

  const markdownCharacterLength = (matchArr[0].length - matchArr[1].length) / 2;
  let newContentState = newEditorState.getCurrentContent(); // remove markdown delimiter at end

  newContentState = _draftJs.Modifier.removeRange(newContentState, wordSelection.merge({
    anchorOffset: wordSelection.getFocusOffset() - markdownCharacterLength
  }));
  let afterSelection = newContentState.getSelectionAfter();
  afterSelection = afterSelection.merge({
    anchorOffset: afterSelection.getFocusOffset() - markdownCharacterLength,
    focusOffset: afterSelection.getFocusOffset() - markdownCharacterLength
  }); // remove markdown delimiter at start

  newContentState = _draftJs.Modifier.removeRange(newContentState, wordSelection.merge({
    focusOffset: wordSelection.getAnchorOffset() + markdownCharacterLength
  })); // apply style

  newContentState = _draftJs.Modifier.applyInlineStyle(newContentState, wordSelection.merge({
    anchorOffset: index,
    focusOffset: focusOffset - markdownCharacterLength * 2
  }), style);
  newEditorState = _draftJs.EditorState.push(editorState, newContentState, "change-inline-style");
  return _draftJs.EditorState.setInlineStyleOverride(_draftJs.EditorState.forceSelection(newEditorState, afterSelection), _immutable.OrderedSet.of(""));
};

var _default = changeCurrentInlineStyle;
exports.default = _default;